/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "game.h"
#include "gametime.h"
#include "input.h"
#include "console/console.h"
#include "net/server/server.h"
#include "net/client/client.h"

int32_t status = 0;

void gameInit() {
  consoleInit();
  gameTimeInit();
  inputInit();

  consolePrint("Press LEFT to start server, RIGHT to join server.");

  memset(&SERVER, 0, sizeof(server_t));
  memset(&CLIENT, 0, sizeof(client_t));

  // serverInit((serverinit_t){
  //   .type = SERVER_TYPE_ONLINE,
  //   .online = {
  //     .port = SERVER_PORT_DEFAULT
  //   }
  // });
}

void gameUpdate(const float delta) {
  gameTimeUpdate(delta);
  inputUpdate();

  switch(status) {
    case 0:
      if(inputWasPressed(INPUT_LEFT)) {

        serverInit((serverinit_t){
          .type = SERVER_TYPE_ONLINE,
          .online = {
            .port = SERVER_PORT_DEFAULT
          }
        });
      } else if(inputWasPressed(INPUT_RIGHT)) {

        clientInit((clientinit_t){
          .host = "127.0.0.1",
          .port = SERVER_PORT_DEFAULT
        });
      }
      break;
  }
}

void gameDispose() {
  clientDispose();
  serverDispose();
}