/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dusk.h"
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <fcntl.h>

#define CLIENT_HOST_STR_LEN 256

typedef enum {
  CLIENT_STATE_DISCONNECTED,
  CLIENT_STATE_CONNECTING,
  CLIENT_STATE_CONNECTED,
  CLIENT_STATE_DISCONNECTING
} clientstate_t;

typedef struct {
  clientstate_t state;
  int32_t socket;
  pthread_t thread;
  struct sockaddr_in serverAddress;
} client_t;

typedef struct {
  char_t host[CLIENT_HOST_STR_LEN+1];
  uint32_t port;
} clientinit_t;

extern client_t CLIENT;

void clientInit(const clientinit_t init);
void clientDispose();
void * clientThread(void* arg);

ssize_t _clientSend(const uint8_t *data, const size_t size);
ssize_t _clientReceive(uint8_t *data, const size_t size);