/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dusk.h"
#include "net/packet.h"
#include <netinet/in.h>
#include <fcntl.h>

typedef enum {
  SERVER_CLIENT_STATE_DISCONNECTED,
  SERVER_CLIENT_STATE_CONNECTING,
  SERVER_CLIENT_STATE_CONNECTED,
  SERVER_CLIENT_STATE_DISCONNECTING
} serverclientstate_t;

typedef struct {
  serverclientstate_t state;
  pthread_t thread;
  int32_t socket;
} serverclient_t;

typedef struct {
  int32_t socket;
} serverclientinit_t;

void serverClientInit(serverclient_t *client, const serverclientinit_t init);
void * serverClientThread(void *arg);

ssize_t serverClientSend(
  serverclient_t *client,
  const uint8_t *data,
  const size_t size
);

ssize_t serverClientReceive(
  serverclient_t *client,
  uint8_t *buffer,
  const size_t size
);

bool_t serverClientSendPacket(
  serverclient_t *client,
  const packet_t *packet
);

void serverClientDispose(serverclient_t *client);